@@ -1,5 +1,5 @@
 package Terse;
-our $VERSION = '0.116';
+our $VERSION = '0.117';
 use 5.006;
 use strict;
 use warnings;
@@ -203,6 +203,7 @@ sub run {
 		return $j->_response($j->response);
 	}
 
+	$j->req = $req;
 	$j->response->authenticated = \1;
 	$j->session = $session;
 
@@ -250,7 +251,7 @@ sub logger {
 }
 
 sub logError {
-	my ($self, $message, $status) = @_;
+	my ($self, $message, $status, $no_response) = @_;
 	$self->{_application} 
 		? $self->response->raiseError($message, $status) 
 		: $self->raiseError($message, $status);
@@ -261,6 +262,7 @@ sub logError {
 		? $self->{_logger}->('error', $message) 
 		: $self->{_logger}->error($message) 
 	if $self->{_logger};
+	$self->response->no_response = 1 if $no_response;
 	return $self;
 }
 
@@ -370,7 +372,7 @@ Terse - Lightweight Web Framework
 
 =head1 VERSION
 
-Version 0.116
+Version 0.117
 
 =cut
 
