@@ -135,9 +135,9 @@ sub delayed_response_handle {
 	my ($self, $t,  $response, $sid, $ct, $status) = @_;
 	$t->{_delayed_response} = sub {
 		my $responder = shift;
-		my $view = $t->view($self->response_view);
+		my $view = $t->view($t->response_view || $self->response_view);
 		my $res = $t->_build_response($sid, 
-			$view ? ($view->content_type || $view->content_type($ct)) : $ct, 
+			$t->content_type || $view && $view->content_type || $ct,
 			$t->response->status_code ||= $status ||= 200
 		);
 		$res = [splice @{$res->finalize}, 0, 2];
@@ -145,13 +145,24 @@ sub delayed_response_handle {
 		$response = eval { $response->($writer); };
 		if ($@ || $t->response->error) {
 			$res->[0] = $t->response->status_code || 500;
-			$t->raiseError($@) if #@;
+			$t->raiseError($@) if $@;
 			push @{$res}, [$t->response->serialize];
 			return $responder->($res);
 		}
 		elsif ($response) {
-			$view = $t->view($self->response_view);
-			$writer->write($view ? [$view->render($t, $response)]->[1] : $response->serialize);
+			$view = $t->view($t->response_view || $self->response_view);
+			if ($view) {
+				my (undef, $render) = $view->render($t, $response);
+				if ($t->response->error) {
+					$res->[0] = $t->response->status_code || 500;
+					push @{$res}, [$t->response->no_response ? () : $t->response->serialize];
+					return $responder->($res);
+				}
+				$response = $render;
+			} else {
+				$response = $response->serialize;
+			}
+			$writer->write($response);
 		}
 		$writer->close;
 	};
@@ -164,11 +175,12 @@ sub response_handle {
 	$ct ||= 'application/json';
 	my $res = $t->{_delayed_response};
 	return $res if ($res);
-	my ($content_type, $body) = $self->views->{$self->response_view} 
-		? $t->view($self->response_view)->render($t, $response_body) 
+	my ($content_type, $body) = $self->views->{$t->response_view || $self->response_view} 
+		? $t->view($t->response_view || $self->response_view)->render($t, $response_body) 
 		: ($ct, $response_body->serialize());
+	$body = undef if $response_body->error && $response_body->no_response;  
 	$res = $t->_build_response($sid, $content_type, $response_body->status_code ||= $status ||= 200);
-	$res->body($body);
+	$res->body($body) if $body;
 	return $res->finalize;
 }
 
@@ -204,6 +216,8 @@ sub dispatch {
 		$t->logError('No callback found to dispatch the request', 400);
 		return;
 	}
+	$t->response_view = $dispatch->{view} if $dispatch->{view};
+	$t->content_type($dispatch->{content_type}) if $dispatch->{content_type};
 	if ($dispatch->{delayed}) {
 		return $t->delayed_response(sub { $self->$callback($t, @params); $t->response; });
 	} elsif ($dispatch->{websocket}) {
@@ -245,7 +259,7 @@ Terse::Controller - controllers made simple.
 
 =head1 VERSION
 
-Version 0.116
+Version 0.117
 
 =cut
 
