@@ -191,17 +191,18 @@ sub recieve {
 	return join "", map { pack "C", ($ENCODED[$_] ^ $MASK[$_ % 4]) } 0 .. $#ENCODED;
 }
 
-__DONE__;
-
 1;
 
+__END__;
+
+
 =head1 NAME
 
 Terse::WebSocket - Lightweight WebSockets
 
 =head1 VERSION
 
-Version 0.116
+Version 0.117
 
 =cut
 
